%global __requires_exclude perl\\\(PDA::Pilot\\\)

%define	lib_major	9
%define	libname		%mklibname pisock %{lib_major}
%define develname	%mklibname pisock -d
%define	libsync		%mklibname pisync %{sync_major}
%define	sync_major	1

Summary:	File transfer utilities between Linux and PalmPilots
Name:		pilot-link
Version:	0.12.5
Release:	%mkrel 40
License:	GPLv2+ and LGPLv2+
Group:		Communications/Mobile
URL:		https://github.com/jichu4n/pilot-link/
# This link is defunct as of 2024
# Alternate link is https://github.com/jichu4n/pilot-link/archive/refs/tags/0.12.5.tar.gz
Source0:	http://www.pilot-link.org/source/pilot-link-%{version}.tar.bz2 
Source1:	connect-palm-ppp.tar.bz2
Source2:	19-palm-acl-management.fdi
Source3:	pilot-device-file.policy
Source4:	50pilot.sh
Source5:	50pilot.csh
# (fc) 0.12.3-3mdv fix undefined value (Fedora)
Patch3:		pilot-link-0.12.1-var.patch
# (fc) 0.12.3-3mdv fix open calls (Fedora)
Patch4:		pilot-link-0.12.5-open.patch
# (fc) 0.12.3-4mdv fix SJ-22 support (Michael Ekstrand)
Patch5:		pilot-link-0.12.3-sj22.patch
#gw this code doesn't work with our setting of Werror
Patch6: 	pilot-link-0.12.3-no-werror-messup.patch
Patch7:		pilot-link-0.12.3-fix-format-strings.patch
# fix build with perl 5.14
Patch8:		pilot-link-0.12.5-build_with_perl514.patch
Patch9:		pilot-link-0.12.3-libpng14.patch
# fix build with autoconf > 2.69
Patch10:	pilot-link-autoconf.patch
Patch11:	pilot-link-configure-c99.patch
Patch12:	pilot-link-c99.patch 
Patch13:	pilot-link-0.12.5-mga-iconv-const.patch
Patch14:	pilot-link-0.12.5-mga-size_t.patch

BuildRequires:	bison
BuildRequires:	perl-devel
BuildRequires:	automake
BuildRequires:	chrpath
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(readline)

Provides:	%{name}-tcl


%description
This suite of tools allows you to upload and download programs and
data files between a Linux/UNIX machine and the PalmPilot.  It has a
few extra utils that will allow for things like syncing the
PalmPilot's calendar app with Ical.  Note that you might still need to
consult the sources for pilot-link if you would like the Python, Tcl,
or Perl bindings.

Install pilot-link if you want to synchronize your Palm with your
Linux system.

%package -n	%{libname}
Summary:	Libraries needed to use pilot-link
Group:		System/Libraries
Requires:	%{name}-common >= %{version}-%{release}

%description -n	%{libname}
Libraries needed to use pilot-link

%package common
Summary:	Files used by pilot-link packages
Group:		Communications/Mobile

%description common
Files used by pilot-link packages.

%package -n	%{libsync}
Summary:	Libraries needed to use pilot-link
Group:		System/Libraries

%description -n	%{libsync}
Libraries needed to use pilot-link

%package -n	%{develname}
Summary:	PalmPilot development header files
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libsync} = %{version}-%{release}
Obsoletes:	%{name}-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	libpisock-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development headers that are used to build
the pilot-link package.  It also includes the static libraries
necessary to build static pilot apps.

If you want to develop PalmPilot synchronizing applications, you'll
need to install this package.

%package -n	perl-PDA-Pilot
Summary:	Perl module for Palm
Group:		Communications/Mobile
Requires:	%{name} = %{version}-%{release}

%description -n	perl-PDA-Pilot
This package provides perl modules for supporting Palm.

%prep
%autosetup -p1 -a 1

%build
autoreconf -vfi
%configure  --with-perl --enable-conduits --enable-libusb --enable-threads --disable-static

# parallel compilation is broken
make

%install
%make_install

# fix manpage install 
%make_install -C doc/man

find %{buildroot} -name '*.la' -delete

find %{buildroot}%{perl_vendorarch} -name "*.so" -exec chmod 755 {} \;

mkdir -p %{buildroot}%{_sysconfdir}/modprobe.d/
cat << EOF > %{buildroot}%{_sysconfdir}/modprobe.d/visor.conf
blacklist visor
EOF

# remove unneeded files
rm -f %{buildroot}%{_libdir}/perl5/*/*/*/PDA/dump.pl

# remove broken prog
rm -f %{buildroot}%{_bindir}/pilot-prc

# Install hal rules file.
mkdir -p %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/
install -p -m644 %{SOURCE2} %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/19-palm-acl-management.fdi

# Install PolicyKit
mkdir -p %{buildroot}%{_datadir}/PolicyKit/policy
install -p -m644 %{SOURCE3} %{buildroot}%{_datadir}/PolicyKit/policy/pilot-device-file.policy

# Install udev rules
mkdir -p %{buildroot}%{_udevrulesdir}
sed -e 's/MODE="0664"$/MODE="0664", ENV{ACL_MANAGE}="1"/g' doc/60-libpisock.rules >  %{buildroot}%{_udevrulesdir}/60-libpisock.rules

# install profile.d files
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/profile.d/
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/

%pre common
if [ -e /etc/modprobe.d/visor ]; then
	mv /etc/modprobe.d/visor{,.conf}
fi

%files
%doc COPYING ChangeLog README NEWS
%doc connect-palm-ppp/
%doc doc/README.usb doc/TODO doc/README.libusb

%{_bindir}/pilot-*
%exclude %{_bindir}/pilot-undelete
%{_mandir}/man1/pilot-*
%{_mandir}/man7/*
%{_datadir}/pilot-link

%files common
%config(noreplace) %{_sysconfdir}/profile.d/50pilot.*
%config(noreplace) %{_sysconfdir}/modprobe.d/visor.conf
%{_udevrulesdir}/*.rules
%{_datadir}/hal/fdi/policy/10osvendor/19-palm-acl-management.fdi
%{_datadir}/PolicyKit/policy/pilot-device-file.policy

%files -n %{libname}
%{_libdir}/libpisock.so.%{lib_major}{,.*}

%files -n %{libsync}
%{_libdir}/libpisync.so.%{sync_major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/*
%{_datadir}/aclocal/pilot-link.m4
%{_libdir}/pkgconfig/*

%files -n perl-PDA-Pilot
%{_bindir}/pilot-undelete
%{_mandir}/man1/ietf2datebook*
%{_mandir}/man3/PDA::Pilot.*
%{perl_vendorarch}/PDA/*
%{perl_vendorarch}/auto/PDA/*


%changelog
* Fri Aug 23 2024 danf <danf> 0.12.5-40.mga10
+ Revision: 2090059
- Fix building with glibc 2.39
- Update links to https:
+ daviddavid <daviddavid>
- add fedora patches to fix build
+ tv <tv>
- Rebuild for perl-5.40

* Tue Dec 05 2023 daviddavid <daviddavid> 0.12.5-39.mga10
+ Revision: 2013226
- rebuild for new perl 5.38.0

* Tue Jun 07 2022 umeabot <umeabot> 0.12.5-38.mga9
+ Revision: 1862730
- Rebuild for Perl 5.36

* Mon Mar 28 2022 umeabot <umeabot> 0.12.5-37.mga9
+ Revision: 1830464
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.12.5-36.mga9
+ Revision: 1727333
- Rebuild for perl 5.34

* Wed Jul 22 2020 wally <wally> 0.12.5-35.mga8
+ Revision: 1607887
- fix build with autoconf > 2.69

* Sat Jun 27 2020 umeabot <umeabot> 0.12.5-34.mga8
+ Revision: 1599468
- Rebuild for perl 5.32

* Wed Feb 19 2020 umeabot <umeabot> 0.12.5-33.mga8
+ Revision: 1542330
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 0.12.5-32.mga8
+ Revision: 1476002
- rebuild for readline

* Tue Aug 27 2019 tmb <tmb> 0.12.5-31.mga8
+ Revision: 1433870
- rebuild for perl 5.30

* Sun Sep 23 2018 umeabot <umeabot> 0.12.5-30.mga7
+ Revision: 1300277
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 daviddavid <daviddavid> 0.12.5-29.mga7
+ Revision: 1249745
- rebuild for new perl 5.28.0
+ kekepower <kekepower>
- Use make_install

* Tue Jan 02 2018 wally <wally> 0.12.5-28.mga7
+ Revision: 1189460
- rebuild for new readline

* Sat Jul 22 2017 neoclust <neoclust> 0.12.5-27.mga7
+ Revision: 1126569
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.12.5-26.mga6
+ Revision: 1036202
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.12.5-25.mga6
+ Revision: 958505
- Mageia 6 Mass Rebuild

* Sat Jun 27 2015 tv <tv> 0.12.5-24.mga6
+ Revision: 846150
- rebuild with soname-ified perl

* Wed Jun 24 2015 sander85 <sander85> 0.12.5-23.mga6
+ Revision: 842086
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.12.5-22.mga5
+ Revision: 740249
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.12.5-21.mga5
+ Revision: 687596
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Jul 05 2014 pterjan <pterjan> 0.12.5-20.mga5
+ Revision: 643770
- Replace libusb*-devel BuildRequires by better ones

* Tue Jun 03 2014 pterjan <pterjan> 0.12.5-19.mga5
+ Revision: 631941
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.12.5-18.mga4
+ Revision: 526190
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 0.12.5-17.mga4
+ Revision: 436037
- rebuild for new libpng

* Wed May 29 2013 fwang <fwang> 0.12.5-16.mga4
+ Revision: 430344
- rebuild for new perl

* Wed Jan 16 2013 fwang <fwang> 0.12.5-15.mga3
+ Revision: 388475
- correct udev rules dir
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 cjw <cjw> 0.12.5-13.mga3
+ Revision: 343444
- patch10: fix build with automake 1.13

* Wed Oct 03 2012 malo <malo> 0.12.5-12.mga3
+ Revision: 302524
- update RPM group

* Thu May 31 2012 jquelin <jquelin> 0.12.5-11.mga3
+ Revision: 252217
- perl 5.16 rebuild

* Thu Sep 22 2011 tmb <tmb> 0.12.5-10.mga2
+ Revision: 146867
- modprobe config files needs to end with .conf (mga #2784)

* Sun Sep 18 2011 fwang <fwang> 0.12.5-9.mga2
+ Revision: 145005
- bump rel
- drop .la files

* Sun Sep 18 2011 fwang <fwang> 0.12.5-8.mga2
+ Revision: 145003
- fix build with latest libpng

* Mon Jun 13 2011 sander85 <sander85> 0.12.5-7.mga2
+ Revision: 105859
- fix build with perl 5.14
- Rebuild for perl 5.14

* Fri Jan 21 2011 ahmad <ahmad> 0.12.5-6.mga1
+ Revision: 29403
- drop old/unneeded scriptlets
- use generic conflicts
- imported package pilot-link

